Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(698)

Unified Diff: ui/views/controls/scrollbar/base_scroll_bar_thumb.h

Issue 2496643002: Implement Sebastien's overlay scrollbars for native UI (Views). (Closed)
Patch Set: fix test failure Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/views/controls/scrollbar/base_scroll_bar_thumb.h
diff --git a/ui/views/controls/scrollbar/base_scroll_bar_thumb.h b/ui/views/controls/scrollbar/base_scroll_bar_thumb.h
index ea16b14ecb4f6efd9b7d9da726fd902bd62572da..7127f434781cdf20f8acbd2c1c081722fc052e41 100644
--- a/ui/views/controls/scrollbar/base_scroll_bar_thumb.h
+++ b/ui/views/controls/scrollbar/base_scroll_bar_thumb.h
@@ -32,8 +32,8 @@ class VIEWS_EXPORT BaseScrollBarThumb : public View {
explicit BaseScrollBarThumb(BaseScrollBar* scroll_bar);
~BaseScrollBarThumb() override;
- // Sets the size (width or height) of the thumb to the specified value.
- void SetSize(int size);
+ // Sets the length (width or height) of the thumb to the specified value.
+ void SetLength(int length);
// Retrieves the size (width or height) of the thumb.
int GetSize() const;
@@ -60,6 +60,9 @@ class VIEWS_EXPORT BaseScrollBarThumb : public View {
CustomButton::ButtonState GetState() const;
// Update our state and schedule a repaint when the mouse moves over us.
void SetState(CustomButton::ButtonState state);
+ virtual void OnStateChanged();
+
+ bool IsHorizontal() const;
BaseScrollBar* scroll_bar() { return scroll_bar_; }
« no previous file with comments | « ui/views/controls/scrollbar/base_scroll_bar.cc ('k') | ui/views/controls/scrollbar/base_scroll_bar_thumb.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698